diff --git a/PocketSharp/IPocketClient.cs b/PocketSharp/IPocketClient.cs
index edf6796..0696fcb 100644
--- a/PocketSharp/IPocketClient.cs
+++ b/PocketSharp/IPocketClient.cs
@@ -116,6 +116,7 @@ namespace PocketSharp
///
/// A simple representation of the saved item which doesn't contain all data (is only returned by calling the Retrieve method)
///
+ /// (1) Uri should be absolute.
///
Task Add(Uri uri, string[] tags = null, string title = null, string tweetID = null);
#endregion
diff --git a/PocketSharp/Components/Add.cs b/PocketSharp/Components/Add.cs
index 75fcca5..598c3e0 100644
--- a/PocketSharp/Components/Add.cs
+++ b/PocketSharp/Components/Add.cs
@@ -16,10 +16,18 @@ namespace PocketSharp
/// A comma-separated list of tags to apply to the item
/// This can be included for cases where an item does not have a title, which is typical for image or PDF URLs. If Pocket detects a title from the content of the page, this parameter will be ignored.
/// If you are adding Pocket support to a Twitter client, please send along a reference to the tweet status id. This allows Pocket to show the original tweet alongside the article.
/// A simple representation of the saved item which doesn't contain all data (is only returned by calling the Retrieve method)
///
public async Task Add(Uri uri, string[] tags = null, string title = null, string tweetID = null)
{
+ if (!uri.IsAbsoluteUri)
+ {
+ throw new FormatException("(1) Uri should be absolute.");
+ }
+
AddParameters parameters = new AddParameters()
{
Uri = uri,
@@ -16,10 +16,18 @@ namespace PocketSharp
/// This can be included for cases where an item does not have a title, which is typical for image or PDF URLs. If Pocket detects a title from the content of the page, this parameter will be ignored.
/// If you are adding Pocket support to a Twitter client, please send along a reference to the tweet status id. This allows Pocket to show the original tweet alongside the article.
- /// A simple representation of the saved item which doesn't contain all data (is only returned by calling the Retrieve method)
+ ///
+ /// A simple representation of the saved item which doesn't contain all data (is only returned by calling the Retrieve method)
+ ///
+ /// (1) Uri should be absolute.
///
public async Task Add(Uri uri, string[] tags = null, string title = null, string tweetID = null)